@@ -15,6 +15,10 @@ class Workspace():
         self._check_data()
         
         
+
+    def __repr__(self):
+        return "<Workspace id={} name={}>".format(self.id, self.name)
+
     @property
     def id(): pass
     @id.getter
@@ -51,7 +55,7 @@ class Workspace():
         for c in cs:
             if c.name.lower() == name.lower():
                 return c
-        print('Couldn\'t find a collection with the name \'{}\''.format(name))
+        raise ValueError('Couldn\'t find a collection with the name \'{}\''.format(name))
         
         
     def get_collection_by_id(self, id):
@@ -59,7 +63,7 @@ class Workspace():
         for c in cs:
             if c.id == id:
                 return c
-        print('Couldn\'t find a collection with the ID \'{}\''.format(id))
+        raise ValueError('Couldn\'t find a collection with the ID \'{}\''.format(id))
         
         
     def show_collections(self):
